@@ -52,7 +52,7 @@ event_sources.json and ${program.eventFile} files as needed.`)
   }
 
   run (program) {
-    if (!['nodejs12.x', 'nodejs14.x'].includes(program.runtime)) {
+    if (!['nodejs12.x', 'nodejs14.x', 'nodejs16.x'].includes(program.runtime)) {
       console.error(`Runtime [${program.runtime}] is not supported.`)
       process.exit(254)
     }
@@ -336,8 +336,7 @@ Emulate only the body of the API Gateway event.
         '.editorconfig',
         '.lambda',
         'deploy.env',
-        '*.log',
-        path.join('build', path.sep)
+        '*.log'
       ]
         .concat(program.excludeGlobs ? program.excludeGlobs.split(' ') : [])
         .concat(excludeNodeModules ? [path.join('node_modules')] : [])
@@ -352,7 +351,7 @@ Emulate only the body of the API Gateway event.
       }
       return str
     }).join(',') + '}'
-    const dirPatternRegExp = new RegExp(`(${dirBlobs.join('|')})$`)
+    const dirPatternRegExp = dirBlobs.length > 0 ? new RegExp(`(${dirBlobs.join('|')})$`) : null
 
     return new Promise((resolve, reject) => {
       fs.mkdirs(dest, (err) => {
@@ -368,10 +367,12 @@ Emulate only the body of the API Gateway event.
             if (!minimatch(src, pattern, { matchBase: true })) {
               return true
             }
+
             // Directory check. Even if `src` is a directory it will not end with '/'.
-            if (!dirPatternRegExp.test(src)) {
+            if (dirPatternRegExp === null || !dirPatternRegExp.test(src)) {
               return false
             }
+
             return !fs.statSync(src).isDirectory()
           }
         }
@@ -973,7 +974,7 @@ they may not work as expected in the Lambda environment.
       console.log(params)
 
       const lambda = new aws.sdk.Lambda({
-        region: region,
+        region,
         apiVersion: '2015-03-31'
       })
       const scheduleEvents = new ScheduleEvents(aws.sdk, region)
